<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs" sourcelanguage="en_US">
<context>
    <name>Application</name>
    <message>
        <location filename="../src/application.cpp" line="427"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/application.cpp" line="104"/>
        <location filename="../src/application.cpp" line="150"/>
        <source>Draw</source>
        <translation>Kreslení</translation>
    </message>
    <message>
        <location filename="../src/application.cpp" line="426"/>
        <source>You can import up to 30 pictures, please try again!</source>
        <translation>Naimportovat je možné nejvýše 30 obrázků. Zkuste to znovu prosím!</translation>
    </message>
</context>
<context>
    <name>BlurWidget</name>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/blurwidget.cpp" line="100"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/blurwidget.cpp" line="110"/>
        <source>Blur</source>
        <translation>Rozmazat</translation>
    </message>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/blurwidget.cpp" line="123"/>
        <source>Mosaic</source>
        <translation>Mozaika</translation>
    </message>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/blurwidget.cpp" line="146"/>
        <source>Width</source>
        <translation>Šířka</translation>
    </message>
</context>
<context>
    <name>CAbstractProcessDialog</name>
    <message>
        <location filename="../src/widgets/dialog/cprogressdialog.cpp" line="105"/>
        <source>Export</source>
        <translation>Export</translation>
    </message>
</context>
<context>
    <name>CAlphaControlWidget</name>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/calphacontrolwidget.cpp" line="65"/>
        <source>Alpha</source>
        <translation>Průhlednost</translation>
    </message>
</context>
<context>
    <name>CCutDialog</name>
    <message>
        <location filename="../src/widgets/dialog/ccutdialog.cpp" line="41"/>
        <source>Discard</source>
        <translation>Zahodit</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/ccutdialog.cpp" line="42"/>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/ccutdialog.cpp" line="47"/>
        <source>Do you want to save the cropped image?</source>
        <translation>Chcete oříznutý obrázek uložit?</translation>
    </message>
</context>
<context>
    <name>CCutTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/ccuttool.cpp" line="90"/>
        <source>Crop (C)</source>
        <translation>Oříznout (C)</translation>
    </message>
</context>
<context>
    <name>CCutWidget</name>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/ccutwidget.cpp" line="230"/>
        <source>Dimensions</source>
        <translation>Rozměry</translation>
    </message>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/ccutwidget.cpp" line="245"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/ccutwidget.cpp" line="295"/>
        <source>Aspect ratio</source>
        <translation>Poměr stran</translation>
    </message>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/ccutwidget.cpp" line="336"/>
        <source>Free</source>
        <translation>Volný</translation>
    </message>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/ccutwidget.cpp" line="343"/>
        <source>Original</source>
        <translation>Původní</translation>
    </message>
</context>
<context>
    <name>CEllipseTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/cellipsetool.cpp" line="57"/>
        <source>Ellipse (O)</source>
        <translation>Elipsa (O)</translation>
    </message>
</context>
<context>
    <name>CEraserTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/cerasertool.cpp" line="98"/>
        <source>Eraser (E)</source>
        <translation>Guma (E)</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cerasertool.cpp" line="113"/>
        <source>Width</source>
        <translation>Šířka</translation>
    </message>
</context>
<context>
    <name>CExportImageDialog</name>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="548"/>
        <source>Percentage</source>
        <translation>Procento</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="562"/>
        <source>Pixels</source>
        <translation>Pixely</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="564"/>
        <source>Dimensions:</source>
        <translation>Rozměry:</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="586"/>
        <source>Lock aspect ratio</source>
        <translation>Zamknout poměr stran</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="595"/>
        <source>W:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="600"/>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="611"/>
        <source>pixels</source>
        <translation>pixelů</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="605"/>
        <source>H:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="868"/>
        <source>It supports up to 10,000 pixels</source>
        <translation>Podporuje až 10000 obrazových bodů</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="98"/>
        <source>Unnamed</source>
        <translation>Bez názvu</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="173"/>
        <source>Export</source>
        <translation>Export</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="186"/>
        <source>Pictures</source>
        <translation>Obrázky</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="188"/>
        <source>Documents</source>
        <translation>Dokumenty</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="189"/>
        <source>Downloads</source>
        <translation>Stažené</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="190"/>
        <source>Desktop</source>
        <translation>Plocha</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="191"/>
        <source>Videos</source>
        <translation>Videa</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="192"/>
        <source>Music</source>
        <translation>Hudba</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="193"/>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="207"/>
        <source>Select other directories</source>
        <translation>Vybrat jiné složky</translation>
    </message>
    <message>
        <source>jpg</source>
        <translation type="vanished">JPG</translation>
    </message>
    <message>
        <source>png</source>
        <translation type="vanished">PNG</translation>
    </message>
    <message>
        <source>bmp</source>
        <translation type="vanished">BMP</translation>
    </message>
    <message>
        <source>tif</source>
        <translation type="vanished">TIFF</translation>
    </message>
    <message>
        <source>pdf</source>
        <translation type="vanished">PDF</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="265"/>
        <source>Name:</source>
        <translation>Název:</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="266"/>
        <source>Save to:</source>
        <translation>Uložit do:</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="268"/>
        <source>Format:</source>
        <translation>Formát:</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="269"/>
        <source>Quality:</source>
        <translation>Kvalita:</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="275"/>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="281"/>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="407"/>
        <source>Cancel</source>
        <translation>Storno</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="276"/>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="282"/>
        <source>Replace</source>
        <translation>Nahradit</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="406"/>
        <source>This file will be hidden if the file name starts with a dot (.). Do you want to hide it?</source>
        <translation>Pokud jeho název bude začínat na tečku (.), bude tento soubor skrytý. Chcete ho skrýt?</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="407"/>
        <source>Confirm</source>
        <translation>Potvrdit</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="421"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="423"/>
        <source>The file name is too long</source>
        <translation>Název souboru je příliš dlouhý</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="506"/>
        <source>%1 
 already exists, do you want to replace it?</source>
        <translation>%1
už existuje. Chcete ho nahradit?</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="866"/>
        <source>At least one pixel please</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CLineTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/clinetool.cpp" line="58"/>
        <source>Line (L)</source>
        <translation>Čára (L)</translation>
    </message>
</context>
<context>
    <name>CPenTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/cpentool.cpp" line="79"/>
        <source>Pencil (P)</source>
        <translation>Tužka (P)</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpentool.cpp" line="96"/>
        <source>Start</source>
        <translation>Začátek</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpentool.cpp" line="124"/>
        <source>End</source>
        <translation>Konec</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpentool.cpp" line="167"/>
        <source>Watercolor</source>
        <translation>Vodovka</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpentool.cpp" line="168"/>
        <source>Calligraphy pen</source>
        <translation>Kaligrafické pero</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpentool.cpp" line="169"/>
        <source>Crayon</source>
        <translation>Voskovka</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpentool.cpp" line="514"/>
        <source>Style</source>
        <translation>Styl</translation>
    </message>
</context>
<context>
    <name>CPictureTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/cpicturetool.cpp" line="87"/>
        <source>Import (I)</source>
        <translation>Import (I)</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpicturetool.cpp" line="114"/>
        <source>Rotate 90° CCW</source>
        <translation>Otočit o 90° doleva</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpicturetool.cpp" line="132"/>
        <source>Rotate 90° CW</source>
        <translation>Otočit o 90° doprava</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpicturetool.cpp" line="149"/>
        <source>Flip horizontally</source>
        <translation>Převrátit vodorovně</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpicturetool.cpp" line="169"/>
        <source>Flip vertically</source>
        <translation>Převrátit svisle</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpicturetool.cpp" line="188"/>
        <source>Auto fit</source>
        <translation>Automatické přizpůsobení</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpicturetool.cpp" line="232"/>
        <source>Import Picture</source>
        <translation>Importovat obrázek</translation>
    </message>
</context>
<context>
    <name>CPolygonTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/cpolygontool.cpp" line="69"/>
        <source>Polygon (H)</source>
        <translation>Mnohoúhelník (H)</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpolygontool.cpp" line="86"/>
        <source>Sides</source>
        <translation>Strany</translation>
    </message>
</context>
<context>
    <name>CPolygonalStarTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/cpolygonalstartool.cpp" line="49"/>
        <source>Star (F)</source>
        <translation>Hvězda (F)</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpolygonalstartool.cpp" line="90"/>
        <source>Points</source>
        <translation>Body</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpolygonalstartool.cpp" line="97"/>
        <source>Radius</source>
        <translation>Poloměr</translation>
    </message>
</context>
<context>
    <name>CRectTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/crecttool.cpp" line="68"/>
        <source>Rectangle (R)</source>
        <translation>Obdélník (R)</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/crecttool.cpp" line="136"/>
        <source>Fill</source>
        <translation>Vyplnit</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/crecttool.cpp" line="142"/>
        <source>Corner Radius</source>
        <translation>Poloměr zaoblení rohu</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/crecttool.cpp" line="273"/>
        <source>Width</source>
        <translation>Šířka</translation>
    </message>
</context>
<context>
    <name>CSelectTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/cselecttool.cpp" line="90"/>
        <source>Select (V)</source>
        <translation>Výběr (V)</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cselecttool.cpp" line="124"/>
        <source>Unnamed</source>
        <translation>Bez názvu</translation>
    </message>
</context>
<context>
    <name>CTextTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/ctexttool.cpp" line="68"/>
        <source>Color</source>
        <translation>Barva</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/ctexttool.cpp" line="99"/>
        <source>Text (T)</source>
        <translation>Text (T)</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/ctexttool.cpp" line="229"/>
        <source>Input text here</source>
        <translation>Sem zadejte text</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/ctexttool.cpp" line="328"/>
        <source>Weight</source>
        <translation>Váha</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/ctexttool.cpp" line="344"/>
        <source>Font</source>
        <translation>Písmo</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/ctexttool.cpp" line="469"/>
        <source>Size</source>
        <translation>Velikost</translation>
    </message>
</context>
<context>
    <name>CTriangleTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/ctriangletool.cpp" line="62"/>
        <source>Triangle (S)</source>
        <translation>Trojúhelník (S)</translation>
    </message>
</context>
<context>
    <name>ColorPanel</name>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/colorpanel.cpp" line="175"/>
        <source>Color</source>
        <translation>Barva</translation>
    </message>
</context>
<context>
    <name>DrawAttribution::CGroupButtonWgt</name>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/cattributeitemwidget.cpp" line="487"/>
        <location filename="../src/frame/AttributesWidgets/private/cattributeitemwidget.cpp" line="499"/>
        <source>Group</source>
        <translation>Seskupit</translation>
    </message>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/cattributeitemwidget.cpp" line="490"/>
        <location filename="../src/frame/AttributesWidgets/private/cattributeitemwidget.cpp" line="507"/>
        <source>Ungroup</source>
        <translation>Zrušit seskupiení</translation>
    </message>
</context>
<context>
    <name>DrawDialog</name>
    <message>
        <location filename="../src/widgets/dialog/drawdialog.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Storno</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/drawdialog.cpp" line="43"/>
        <source>Discard</source>
        <translation>Zahodit</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/drawdialog.cpp" line="44"/>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/drawdialog.cpp" line="47"/>
        <source>Save the current contents?</source>
        <translation>Uložit stávající obsah?</translation>
    </message>
</context>
<context>
    <name>FileHander</name>
    <message>
        <location filename="../src/service/filehander.cpp" line="596"/>
        <source>Opening...</source>
        <translation>Otevírání…</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="623"/>
        <source>Saving...</source>
        <translation>Ukládání…</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="650"/>
        <source>Damaged file, unable to open it</source>
        <translation>Poškozený soubor – není možné ho otevřít</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="705"/>
        <location filename="../src/service/filehander.cpp" line="828"/>
        <source>The file does not exist</source>
        <translation>Tento soubor neexistuje</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="724"/>
        <source>Unable to open &quot;%1&quot;, unsupported file format</source>
        <translation>„%1“ se nedaří otevřít – nepodporovaný formát souboru</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="749"/>
        <source>The file name must not contain \/:*?&quot;&lt;&gt;|</source>
        <translation>Je třeba, aby název souboru neobsahoval \/:*?&quot;&lt;&gt;|</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="839"/>
        <source>Unable to open the write-only file &quot;%1&quot;</source>
        <translation>Nedaří se otevřít soubor „%1“, který je pouze pro zápis</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="852"/>
        <source>This file is read-only, please save with another name</source>
        <translation>Tento soubor je pouze pro čtení – prosím uložte pod jiným názvem</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="860"/>
        <source>You do not have permission to save files here, please change and retry</source>
        <translation>Nemáte oprávnění sem ukládat soubory, změňte je a zkuste to znovu</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="881"/>
        <source>The file is incompatible with the old app, please install the latest version</source>
        <translation>Soubor není kompatibilní se starou verzí aplikace – nainstalujte prosím nejnovější verzi</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="899"/>
        <source>Unable to open the broken file &quot;%1&quot;</source>
        <translation>Nedaří se otevřít poškozený soubor „%1“</translation>
    </message>
</context>
<context>
    <name>FileSelectDialog</name>
    <message>
        <location filename="../src/frame/cmultiptabbarwidget.cpp" line="202"/>
        <source>The file name must not contain \/:*?&quot;&lt;&gt;|</source>
        <translation>Je třeba, aby název souboru neobsahoval \/:*?&quot;&lt;&gt;|</translation>
    </message>
    <message>
        <location filename="../src/frame/cmultiptabbarwidget.cpp" line="204"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/frame/cmultiptabbarwidget.cpp" line="231"/>
        <source>Cannot save it as %1, since the file in that name is open now.
Please save it in another name or close that file and try again.</source>
        <translation>Není možné uložit jako %1, protože soubor s tímto názvem je nyní otevřený.
Prosím uložte ho pod jiným názvem nebo ten soubor zavřete a zkuste to znovu.</translation>
    </message>
</context>
<context>
    <name>IBlurTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/cmasicotool.cpp" line="148"/>
        <source>Blur (B)</source>
        <translation>Rozmazání (B)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/frame/mainwindow.cpp" line="105"/>
        <source>Draw</source>
        <translation>Kreslit</translation>
    </message>
    <message>
        <location filename="../src/frame/mainwindow.cpp" line="200"/>
        <source>Export successful</source>
        <translation>Export úspěšný</translation>
    </message>
    <message>
        <location filename="../src/frame/mainwindow.cpp" line="200"/>
        <source>Export failed</source>
        <translation>Export se nezdařil</translation>
    </message>
    <message>
        <location filename="../src/frame/mainwindow.cpp" line="228"/>
        <source>Open</source>
        <translation>Otevřít</translation>
    </message>
</context>
<context>
    <name>PageContext</name>
    <message>
        <location filename="../src/drawshape/cdrawparamsigleton.cpp" line="66"/>
        <source>Unnamed</source>
        <translation>Bez názvu</translation>
    </message>
</context>
<context>
    <name>PageView</name>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="322"/>
        <location filename="../src/frame/cgraphicsview.cpp" line="666"/>
        <source>Layer</source>
        <translation>Vrstva</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="324"/>
        <location filename="../src/frame/cgraphicsview.cpp" line="683"/>
        <source>Cut</source>
        <translation>Vyjmout</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="329"/>
        <location filename="../src/frame/cgraphicsview.cpp" line="684"/>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="334"/>
        <location filename="../src/frame/cgraphicsview.cpp" line="685"/>
        <source>Paste</source>
        <translation>Vložit</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="341"/>
        <location filename="../src/frame/cgraphicsview.cpp" line="686"/>
        <source>Select All</source>
        <translation>Vybrat vše</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="348"/>
        <location filename="../src/frame/cgraphicsview.cpp" line="692"/>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="354"/>
        <location filename="../src/frame/cgraphicsview.cpp" line="687"/>
        <source>Undo</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="363"/>
        <location filename="../src/frame/cgraphicsview.cpp" line="688"/>
        <source>Redo</source>
        <translation>Znovu</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="372"/>
        <source>Raise Layer</source>
        <translation>Přesunout vrstvu o úroveň níž</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="377"/>
        <source>Lower Layer</source>
        <translation>Přesunout vrstvu o úroveň níže</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="382"/>
        <source>Layer to Top</source>
        <translation>Přesunout vrstvu úplně nahoru</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="387"/>
        <source>Layer to Bottom</source>
        <translation>Přesunout vrstvu úplně dospod</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="416"/>
        <source>Group</source>
        <translation>Seskupit</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="421"/>
        <source>Ungroup</source>
        <translation>Zrušit seskupení</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="427"/>
        <source>Align</source>
        <translation>Zarovnat</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="430"/>
        <source>Align left</source>
        <translation>Zarovnat vlevo</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="435"/>
        <source>Horizontal centers</source>
        <translation>Vodorovné vystředení</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="440"/>
        <source>Align right</source>
        <translation>Zarovnat vpravo</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="445"/>
        <source>Align top</source>
        <translation>Zarovnat nahoru</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="450"/>
        <source>Vertical centers</source>
        <translation>Svislé vystředění</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="455"/>
        <source>Align bottom</source>
        <translation>Zarovnat dolů</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="460"/>
        <source>Distribute horizontal space</source>
        <translation>Rozmístit vodorovný prostor</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="462"/>
        <source>Distribute vertical space</source>
        <translation>Rozmístit svislý prostor</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="689"/>
        <source>Text Align Left</source>
        <translation>Zarovnat text doleva</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="690"/>
        <source>Text Align Right</source>
        <translation>Zarovnat text doprava</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="691"/>
        <source>Text Align Center</source>
        <translation>Zarovnat text na střed</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/frame/mainwindow.cpp" line="75"/>
        <location filename="../src/frame/cviewmanagement.cpp" line="202"/>
        <source>File not saved</source>
        <translation>Soubor neuložen</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/ctexttool.cpp" line="355"/>
        <source>Source Han Sans CN</source>
        <translation>Source Han Sans CN</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/crecttool.cpp" line="84"/>
        <source>Stroke</source>
        <translation>Tah</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="103"/>
        <source>The blur effect will be lost as the file is in old version. Proceed to open it?</source>
        <translation>Efekt rozmazání bude ztracen, protože soubor je ve staré verzi. Pokračovat v jeho otevírání?</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="104"/>
        <location filename="../src/service/filehander.cpp" line="129"/>
        <location filename="../src/service/filehander.cpp" line="203"/>
        <source>Open</source>
        <translation>Otevřít</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="104"/>
        <location filename="../src/service/filehander.cpp" line="129"/>
        <location filename="../src/service/filehander.cpp" line="203"/>
        <location filename="../src/frame/ccentralwidget.cpp" line="757"/>
        <location filename="../src/frame/AttributesWidgets/private/ccutwidget.cpp" line="385"/>
        <source>Cancel</source>
        <translation>Storno</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="128"/>
        <location filename="../src/service/filehander.cpp" line="202"/>
        <source>The file is in an older version, and the properties of elements will be changed. Proceed to open it?</source>
        <translation>Soubor je starší verze a vlastnosti prvků budou změněny. Pokračovat v otevírání?</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="462"/>
        <source>Unable to save. There is not enough disk space.</source>
        <translation>Nedaří se uložit. Na disku není dost místa.</translation>
    </message>
    <message>
        <location filename="../src/frame/ccentralwidget.cpp" line="287"/>
        <source>Unnamed</source>
        <translation>Bez názvu</translation>
    </message>
    <message>
        <location filename="../src/frame/ccentralwidget.cpp" line="300"/>
        <source>The dimensions of %1 exceed the canvas. How to display it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/frame/ccentralwidget.cpp" line="289"/>
        <location filename="../src/frame/ccentralwidget.cpp" line="301"/>
        <source>Keep original size</source>
        <translation>Zachovat původní velikost</translation>
    </message>
    <message>
        <location filename="../src/frame/ccentralwidget.cpp" line="289"/>
        <location filename="../src/frame/ccentralwidget.cpp" line="301"/>
        <source>Auto fit</source>
        <translation>Automatické přizpůsobení</translation>
    </message>
    <message>
        <location filename="../src/frame/ccentralwidget.cpp" line="296"/>
        <source>Apply to all</source>
        <translation>Použít na vše</translation>
    </message>
    <message>
        <location filename="../src/frame/ccentralwidget.cpp" line="755"/>
        <source>%1 has been modified in other programs. Do you want to reload it?</source>
        <translation>%1 bylo mezitím změněno jiným programem. Chcete ho znovu načíst?</translation>
    </message>
    <message>
        <location filename="../src/frame/ccentralwidget.cpp" line="756"/>
        <source>Reload</source>
        <translation>Načíst znovu</translation>
    </message>
    <message>
        <location filename="../src/frame/ccentralwidget.cpp" line="1289"/>
        <location filename="../src/frame/ccentralwidget.cpp" line="1691"/>
        <source>Import failed: no more than 10,000 pixels please</source>
        <translation>Nepodařil se zavést: ne více než 10000 obrazových bodů</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/dialog.h" line="45"/>
        <location filename="../src/frame/AttributesWidgets/private/ccutwidget.cpp" line="374"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/widgets/progresslayout.cpp" line="37"/>
        <location filename="../src/frame/ccentralwidget.cpp" line="1224"/>
        <source>Opening...</source>
        <translation>Otevírání…</translation>
    </message>
    <message>
        <location filename="../src/widgets/progresslayout.cpp" line="158"/>
        <source>%1/%2</source>
        <translation>%1/%2</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="vanished">Vybrat vše</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="vanished">Vyjmout</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation type="vanished">Zpět</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="vanished">Kopírovat</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation type="vanished">Vložit</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">Smazat</translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="vanished">Seskupit</translation>
    </message>
    <message>
        <source>Ungroup</source>
        <translation type="vanished">Zrušit seskupení</translation>
    </message>
    <message>
        <source>pdf</source>
        <translation type="vanished">PDF</translation>
    </message>
    <message>
        <location filename="../src/application.cpp" line="72"/>
        <location filename="../src/application.cpp" line="80"/>
        <source>DDF Drawings</source>
        <translation>Výkresy DDF</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="34"/>
        <source>Files</source>
        <translation>Soubory</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="35"/>
        <source>Drawing</source>
        <translation>Kreslení</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="36"/>
        <source>Shapes/Images</source>
        <translation>Tvary/obrázky</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="37"/>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="38"/>
        <source>Align</source>
        <translation>Zarovnat</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="42"/>
        <source>New</source>
        <translation>Nový</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="43"/>
        <source>Open</source>
        <translation>Otevřít</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="44"/>
        <source>Export</source>
        <translation>Export</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="45"/>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="46"/>
        <source>Save as</source>
        <translation>Uložit jako</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="47"/>
        <source>Print</source>
        <translation>Tisk</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="50"/>
        <source>Select</source>
        <translation>Vybrat</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="51"/>
        <source>Import</source>
        <translation>Import</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="52"/>
        <source>Rectangle</source>
        <translation>Obdélník</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="53"/>
        <source>Ellipse</source>
        <translation>Elipsa</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="54"/>
        <source>Triangle</source>
        <translation>Trojúhelník</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="55"/>
        <source>Star</source>
        <translation>Hvězda</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="56"/>
        <source>Polygon</source>
        <translation>Mnohoúhelník</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="57"/>
        <source>Line</source>
        <translation>Čára</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="59"/>
        <source>Pencil</source>
        <translation>Tužka</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="58"/>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="60"/>
        <source>Eraser</source>
        <translation>Guma</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="61"/>
        <source>Blur</source>
        <translation>Rozmazání</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="62"/>
        <source>Crop</source>
        <translation>Ořezání</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="63"/>
        <source>Expand canvas</source>
        <translation>Zvětšit plátno</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="64"/>
        <source>Shrink canvas</source>
        <translation>Zmenšit plátno</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="69"/>
        <source>Cut</source>
        <translation>Vyjmout</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="70"/>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="71"/>
        <source>Paste</source>
        <translation>Vložit</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="72"/>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="73"/>
        <source>Undo</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="74"/>
        <source>Redo</source>
        <translation>Znovu</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="75"/>
        <source>Group</source>
        <translation>Seskupit</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="76"/>
        <source>Ungroup</source>
        <translation>Zrušit seskupení</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="77"/>
        <source>Raise Layer</source>
        <translation>Přesunout vrstvu o úroveň níž</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="78"/>
        <source>Lower Layer</source>
        <translation>Přesunout vrstvu o úroveň níže</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="79"/>
        <source>Layer to Top</source>
        <translation>Přesunout vrstvu úplně nahoru</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="80"/>
        <source>Layer to Bottom</source>
        <translation>Přesunout vrstvu úplně dospod</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="84"/>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="85"/>
        <source>Display shortcuts</source>
        <translation>Zobrazit klávesové zkratky</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="87"/>
        <source>Align left</source>
        <translation>Zarovnat vlevo</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="88"/>
        <source>Align right</source>
        <translation>Zarovnat vpravo</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="89"/>
        <source>Horizontal centers</source>
        <translation>Vodorovné vystředení</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="90"/>
        <source>Align top</source>
        <translation>Zarovnat nahoru</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="91"/>
        <source>Align bottom</source>
        <translation>Zarovnat dolů</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="92"/>
        <source>Vertical centers</source>
        <translation>Svislé vystředění</translation>
    </message>
</context>
<context>
    <name>TabBarWgt</name>
    <message>
        <location filename="../src/frame/cmultiptabbarwidget.cpp" line="120"/>
        <source>Close tab</source>
        <translation>Zavřít panel</translation>
    </message>
    <message>
        <location filename="../src/frame/cmultiptabbarwidget.cpp" line="125"/>
        <source>Close other tabs</source>
        <translation>Zavřít ostatní panely</translation>
    </message>
</context>
<context>
    <name>TopTilte</name>
    <message>
        <location filename="../src/frame/toptoolbar.cpp" line="173"/>
        <source>New</source>
        <translation>Nový</translation>
    </message>
    <message>
        <location filename="../src/frame/toptoolbar.cpp" line="178"/>
        <source>Open</source>
        <translation>Otevřít</translation>
    </message>
    <message>
        <location filename="../src/frame/toptoolbar.cpp" line="199"/>
        <location filename="../src/frame/toptoolbar.cpp" line="225"/>
        <source>Export</source>
        <translation>Export</translation>
    </message>
    <message>
        <location filename="../src/frame/toptoolbar.cpp" line="189"/>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <location filename="../src/frame/toptoolbar.cpp" line="194"/>
        <source>Save as</source>
        <translation>Uložit jako</translation>
    </message>
    <message>
        <location filename="../src/frame/toptoolbar.cpp" line="209"/>
        <source>Print</source>
        <translation>Tisk</translation>
    </message>
    <message>
        <location filename="../src/frame/toptoolbar.cpp" line="242"/>
        <source>Draw</source>
        <translation>Kreslení</translation>
    </message>
    <message>
        <location filename="../src/frame/toptoolbar.cpp" line="245"/>
        <source>Draw is a lightweight drawing tool for users to freely draw and simply edit images. </source>
        <translation>Kreslení je jednoduchý kreslicí nástroj pro uživatele, aby mohli kreslit od ruky a provádět jednoduché úpravy obrázků.</translation>
    </message>
</context>
</TS>
